@@ -229,7 +229,7 @@ apply_config (struct DisplayInfo *info)
 					      gdk_x11_drawable_get_xid (GDK_DRAWABLE (root_window)),
 					      new_res,
 					      new_rot,
-					      new_rate,
+					      new_rate > 0 ? new_rate : 0,
 					      GDK_CURRENT_TIME);
 	}
     }
@@ -277,7 +277,7 @@ revert_config (struct DisplayInfo *info)
 					  gdk_x11_drawable_get_xid (GDK_DRAWABLE (root_window)),
 					  screen_info->old_size,
 					  screen_info->old_rotation,
-					  screen_info->old_rate,
+					  screen_info->old_rate > 0 ? screen_info->old_rate : 0,
 					  GDK_CURRENT_TIME);
       
     }
@@ -314,7 +314,7 @@ wrap_in_label (GtkWidget *child, char *text)
   vbox = gtk_vbox_new (FALSE, 6);
   label = NULL;
 
-  label = gtk_label_new ("");
+  label = gtk_label_new (NULL);
 
   str = g_strdup_printf ("<b>%s</b>", text);
   gtk_label_set_markup (GTK_LABEL (label), str);
@@ -491,11 +491,11 @@ static GtkWidget *
 create_rotate_menu (struct ScreenInfo *screen_info)
 {
   GtkComboBox* combo = NULL;
+  int i, item = 0, current_item = -1;
+
   screen_info->rotate_widget = gtk_combo_box_new_text ();
   combo = GTK_COMBO_BOX(screen_info->rotate_widget);
 
-  int i, item = 0, current_item = -1;
-
   for (i = 0; i < G_N_ELEMENTS (rotations); i++)
   {
     if ((screen_info->rotations & rotations[i].rotation) != 0)
@@ -664,13 +664,13 @@ create_dialog (struct DisplayInfo *info)
       client = gconf_client_get_default ();
       key = g_strconcat ("/desktop/gnome/screen/", hostname,  "/0/resolution",NULL);
       resolution = gconf_client_get_string (client, key, NULL);
-      g_free (resolution);
       g_free (key);
       g_object_unref (client);
       
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (per_computer_check),
 				    resolution != NULL);
       info->was_per_computer = resolution != NULL;
+      g_free (resolution);
       
       gtk_widget_show (per_computer_check);
       
@@ -678,6 +678,8 @@ create_dialog (struct DisplayInfo *info)
       gtk_box_pack_start (GTK_BOX (vbox),
 			  wrapped, FALSE, FALSE, 0);
       gtk_widget_show (wrapped);
+
+      g_free (resolution);
     }
 
   info->per_computer_check = per_computer_check;
