@@ -1029,21 +1029,25 @@ main (int argc, char **argv)
 	GConfChangeSet *changeset;
 	GladeXML       *dialog;
 	GtkWidget      *dialog_win;
+	GOptionContext *context;
 
 	static gboolean get_legacy;
-	static struct poptOption cap_options[] = {
-		{ "get-legacy", '\0', POPT_ARG_NONE, &get_legacy, 0,
+	static GOptionEntry cap_options[] = {
+		{ "get-legacy", 0, 0, G_OPTION_ARG_NONE, &get_legacy,
 		  N_("Retrieve and store legacy settings"), NULL },
-		{ NULL, '\0', 0, NULL, 0, NULL, NULL }
+		{ NULL }
 	};
 
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	context = g_option_context_new (_("- GNOME Mouse Preferences"));
+	g_option_context_add_main_entries (context, cap_options, GETTEXT_PACKAGE);
+
 	gnome_program_init ("gnome-mouse-properties", VERSION,
 			    LIBGNOMEUI_MODULE, argc, argv,
-			    GNOME_PARAM_POPT_TABLE, cap_options,
+			    GNOME_PARAM_GOPTION_CONTEXT, context,
 			    GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 			    NULL);
 
