@@ -249,6 +249,7 @@ layout_shell (AppShellData * app_data, const gchar * filter_title, const gchar *
 	GtkWidget *sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC,
 		GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_IN);
 	gtk_container_add (GTK_CONTAINER (sw), app_data->category_layout);
 	GtkAdjustment *adjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (sw));
 	g_object_set (adjustment, "step-increment", (double) 20, NULL);
@@ -665,7 +666,7 @@ create_application_category_sections (AppShellData * app_data)
 			G_CALLBACK (handle_group_clicked), app_data);
 
 		gchar *markup =
-			g_markup_printf_escaped ("<span size=\"x-large\">%s</span>",
+			g_markup_printf_escaped ("<span size=\"x-large\" weight=\"bold\">%s</span>",
 			data->category);
 		data->section = SLAB_SECTION (slab_section_new_with_markup (markup, Style2));
 
