@@ -258,7 +258,7 @@ create_populate_combo_box()
 	for(index = 0; index < MAPPING_SIZE; index++) {
 		gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _(mapping_logicalnames[index]));
 	}
-	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), "Select sound file...");
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box), _("Select sound file..."));
 
 	return combo_box;
 }
